import re
def sam2zz(sam_in_dir=0,fa_in_dir=0,zz_out_dir=0):


	#-----------------------------------------------------------
	#reading refgenome
	fref=open(fa_in_dir)
	chrom={}
	chrr=''
	line=fref.read()
	line=line.split('>')
	for seq in line:
			if ' ' in seq:
				chrr=seq[0:seq.find(' ')]
			else:
				chrr=seq[0:seq.find('\n')]
			chrom[chrr]=seq[seq.find('\n'):].replace('\n','')

	#0 base

	fref.close()
	#------------------------------------------------------------
	#
	#donee:dolist;lst:donumlist
	def doCG(a):
		donee=[]
		lst=re.findall( '(\d+|\+|-|\*|/)', a )
		for i in a:
			if i == 'I' or i == 'D' or i== 'M' or i=='S' or i=='P' or i=='N' :
				donee.append(i)
		return donee,lst
	#donefunction

	def doneCG(CG,chrr,pos,seq,qseq):#pos is 1 base
		donee,lst=doCG(CG)
		errorsite=''
		intersite=''
		quasite=''
		locsite=''
		pieceloc=''
		refseq=''
		seqseq=''
		refpos=int(pos)-1
		seqpos=0
		step=0
		while step<len(donee):
			if donee[step]=='I':
				seqpos=seqpos+int(lst[step])
			elif donee[step]=='D':
				refpos=refpos+int(lst[step])
			elif donee[step]=='N':
				refpos=refpos+int(lst[step])
			elif donee[step]=='S':
				seqpos=seqpos+int(lst[step])
			elif donee[step]=='M':
				
				refseq=refseq+chrom[chrr][refpos:refpos+int(lst[step])]
				seqseq=seqseq+seq[seqpos:seqpos+int(lst[step])]
				j=refpos
				jj=seqpos
				while j<refpos+int(lst[step]):
					try:
						if chrom[chrr][j].upper() != seq[jj].upper() and chrom[chrr][j].upper() !='N' and seq[jj].upper() != 'N':
							errorsite=errorsite+chrom[chrr][j].upper()+seq[jj].upper()+':'+str(j+1)+';'
							quasite=quasite+','+str(ord(qseq[jj]))
							locsite=locsite+','+str(jj+1)
							pieceloc=pieceloc+','+str( min( jj+1-seqpos,seqpos+int(lst[step])-jj  ) )
							 		
					except Exception, e:
						pass
						#print "error with",chrr,pos,e
					j=j+1
					jj=jj+1
				intersite=intersite+str(refpos+1)+':'+str(refpos+int(lst[step]))+';'
				refpos=refpos+int(lst[step])
				seqpos=seqpos+int(lst[step])
			step=step+1
		refseq=refseq.upper()
		seqseq=seqseq.upper()
		return refseq,seqseq,errorsite,intersite,quasite,locsite,pieceloc
	#------------------------------------------------------------
	###################additional
	'''
	whole={}
	fi=open(sam_in_dir)
	for line in fi:
		seq=line.split('\t')
		if line[0]!='@'and len(seq)>5:
			if seq[0][0]!='@' and seq[2]!='*' and seq[5]!='*':
				name=seq[0].split('_|_')[0]
				
				#tmp = [ seq[4].count(':') ,seq[0] ]
				if name in whole:
				#	if tmp[0] < whole[name][0]:
				#		whole[name]=tmp
					
					whole[name] +=1
				else:
					whole[name]=1
					#whole[name]=tmp
	fi.close()
	'''
	#######################			
	fi=open(sam_in_dir) #sam
	fo=open(zz_out_dir,'w') #zz
	for line in fi:
		seq=line.split('\t')
		if line[0]!='@' and len(seq)>5:
			name=seq[0].split('_|_')[0]
			if seq[0][0]!='@' and seq[2]!='*' and seq[5]!='*' :# and whole[name]<2:
				refseq,seqseq,errorsite,intersite,quasite,locsite,pieceloc=doneCG(seq[5],seq[2],seq[3],seq[9],seq[10])
				quasite=quasite[1:]
				locsite=locsite[1:]
				pieceloc=pieceloc[1:]
				
				if len(intersite[0:-1])==0:
					intersite='*;'
				if len(errorsite[0:-1])==0:
					errorsite='*;'
				if len(quasite)==0:
					quasite='*'
				if len(locsite)==0:
					locsite='*'
				if len(pieceloc)==0:
					pieceloc='*'
				
				if len(bin(int(seq[1])))>=9 and bin(int(seq[1]))[-7]=='1':
					fo.write(seq[2]+'\t'+seq[1]+'\t'+seq[4]+'\t'+intersite[0:-1]+'\t'+errorsite[0:-1]+'\t'+quasite+'\t'+locsite+'\t'+seq[9]+'\t'+seq[0]+'_1'+'\t'+pieceloc+'\n')
				elif len(bin(int(seq[1])))>=10 and bin(int(seq[1]))[-8]=='1':
					fo.write(seq[2]+'\t'+seq[1]+'\t'+seq[4]+'\t'+intersite[0:-1]+'\t'+errorsite[0:-1]+'\t'+quasite+'\t'+locsite+'\t'+seq[9]+'\t'+seq[0]+'_2'+'\t'+pieceloc+'\n')
				else:
					fo.write(seq[2]+'\t'+seq[1]+'\t'+seq[4]+'\t'+intersite[0:-1]+'\t'+errorsite[0:-1]+'\t'+quasite+'\t'+locsite+'\t'+seq[9]+'\t'+seq[0]+'\t'+pieceloc+'\n')
					
	fi.close()	
	fo.close()




#use .bed to annotate .bed
def annotate(bed_in_dir=0,bed_anno_dir=0,bed_out_dir=0):
	if bed_in_dir ==0 or bed_anno_dir ==0 or bed_out_dir ==0:
		print 'Please check the input directory! annotate(bed_in_dir,bed_anno_dir,bed_out_dir)'
		return 'Please check the input directory! annotate(bed_in_dir,bed_anno_dir,bed_out_dir)'
	else:
		fi=open(bed_in_dir) #must by sorted
		fa=open(bed_anno_dir)
		fo=open(bed_out_dir,'w')
		anno={}
		for line in fa:
			seq=line[0:-1].split('\t')
			try:
				anno[seq[0]].append([int(seq[1])+1,int(seq[2]),seq[3],seq[4],seq[5]])	
			except Exception, e:
				anno[seq[0]]=[ [int(seq[1])+1,int(seq[2]),seq[3],seq[4],seq[5]]  ]
		for a in anno:
			anno[a].sort()
		top=0
		point=0
		lastchr=''
		for line in fi:
		
			seq = line.split()
			if len(seq[0]) <=5:
				output=line[0:-1]
				if seq[0]==lastchr:
					1+1
				else:
					top=0
					lastchr=seq[0]
				if seq[0] not in anno:
					anno[seq[0]]=[ [0,0,0,0,0]  ]
				if top<len(anno[seq[0]]):			
					while anno[seq[0]][top][1] < int(seq[2]) :
		
						top=top+1
						if top >= len(anno[seq[0]]):
							break
					point=top
					if point < len(anno[seq[0]]):
						while anno[seq[0]][point][0] <= int(seq[2])     and     anno[seq[0]][point][1] >= int(seq[2]) :
								if anno[seq[0]][point][2]+'\t'+anno[seq[0]][point][3]+'\t'+anno[seq[0]][point][4] not in output:
									output=output+'\t'+anno[seq[0]][point][2]+'\t'+anno[seq[0]][point][3]+'\t'+anno[seq[0]][point][4]
								point=point+1
								if point >= len(anno[seq[0]]):
									break
		
				fo.write(output+'\n')
		fi.close()
		fa.close()
		fo.close()




import subprocess,sprint,os,sys

def prepare():
    import subprocess,sprint,os,sys
    print ''
    print "##############################################################################################"
    print ''
    print "   SPRINT: SNP-free RNA editing Identification Toolkit"
    print ""
    print "   http://sprint.tianlab.cn/SPRINT/"
    print ""
    print "   Please contact with 15110700005@fudan.edu.cn when questions arise."
    print ""
    print "##############################################################################################"
    
    def help_doc():
        print ""
        print "   Usage:"
        print ""
        print "      sprint prepare   [options]   reference_genome(.fa)   bwa_path"
        print ""
        print "      options:"
        print "         -t transcript_annotation(.gtf) #Optional"
        print ""
        print "   Example:"
        print ""
        print "      sprint prepare -t hg19.gtf hg19.fa ./bwa-0.7.12/bwa"
        print ""
        print ""
        #print sys.argv[0]
    
        sys.exit(0)
    
    if len(sys.argv)<3:
        help_doc()
    
    
    
    gtf_file=False
    options=[]
    read2=''
    i=1
    while i< len(sys.argv):
        if sys.argv[i]=='-t':
            paired_end=True
            try:
                gtf_file=sys.argv[i+1]
                options.append(i)
                options.append(i+1)
            except Exception, e:
                print 'options error!'
                help_doc()
    
    
        i += 1
    
    all_argv=[]
    i=1
    while i< len(sys.argv):
        if i not in options:
            all_argv.append(i)
        i +=1
    
    try:
        refgenome=sys.argv[all_argv[0]]
        #gtf_file=sys.argv[2]
        bwa=sys.argv[all_argv[1]]
    
    
    
    
    
        print 'Masking A with G in reference genome...'
        sprint.maskAwithG(refgenome,refgenome+'.mskAG.fa')
        print 'Masking T with C in reference genome...'
        sprint.maskTwithC(refgenome,refgenome+'.mskTC.fa')
       
        if gtf_file != False:
            print 'Assembling transcripts...'
            sprint.transcript_assembler(refgenome,gtf_file,refgenome+'.trans.fa')
            print 'Masking A with G in transcripts...'
            sprint.maskAwithG(refgenome+'.trans.fa',refgenome+'.trans.fa.mskAG.fa')
            print 'Masking T with C in transcripts...'
            sprint.maskTwithC(refgenome+'.trans.fa',refgenome+'.trans.fa.mskTC.fa')
    
    
        print 'Building BWA index...'
        step1=subprocess.Popen(bwa+' index -a bwtsw '+refgenome,shell=True)
        step2=subprocess.Popen(bwa+' index -a bwtsw '+refgenome+'.mskAG.fa',shell=True)
        step3=subprocess.Popen(bwa+' index -a bwtsw '+refgenome+'.mskTC.fa',shell=True)
        if gtf_file !=False:
            step4=subprocess.Popen(bwa+' index -a bwtsw '+refgenome+'.trans.fa',shell=True)
            step5=subprocess.Popen(bwa+' index -a bwtsw '+refgenome+'.trans.fa.mskAG.fa',shell=True)
            step6=subprocess.Popen(bwa+' index -a bwtsw '+refgenome+'.trans.fa.mskTC.fa',shell=True)
            step4.wait()
            step5.wait()
            step6.wait()
        step1.wait()
        step2.wait()
        step3.wait()
        sys.exit(0)    
    except Exception, e:
        print "ERROR!"
        print ""
        print e
        help_doc()
    
    
    
    
    
#if __name__ == "__main__": 
#    prepare()



def seperate(bed_in_dir,flag_out_dir,rp_out_dir,nonrp_out_dir,flag):
	fi=open(bed_in_dir)
	fo_flag=open(flag_out_dir,'w')
	fo_rp=open(rp_out_dir,'w')
	fo_nonrp=open(nonrp_out_dir,'w')
	for line in fi:
		if 'Simple_repeat' in line or 'Low_complexity' in line:
			next
		elif flag in line:
			fo_flag.write(line)
		elif 'Repeat_region' in line:
			fo_rp.write(line)
		else:
			fo_nonrp.write(line)
	fi.close()
	fo_flag.close()
	fo_rp.close()
	fo_nonrp.close()



def combine_res(bed_in_dir1,bed_in_dir2,bed_in_dir3,bed_out_dir):
	f1=open(bed_in_dir1)
	f2=open(bed_in_dir2)
	f3=open(bed_in_dir3)
	fo=open(bed_out_dir,'w')
	whole=[]
	for line in f1:
		seq=line.replace('\n','').split('\t')
		whole.append([seq[0],int(seq[2]),seq[3],seq[4],seq[5]])
	for line in f2:
		seq=line.replace('\n','').split('\t')
		whole.append([seq[0],int(seq[2]),seq[3],seq[4],seq[5]])
	for line in f3:
		seq=line.replace('\n','').split('\t')
		whole.append([seq[0],int(seq[2]),seq[3],seq[4],seq[5]])
	whole.sort()
	for one in whole:
		fo.write(one[0]+'\t'+str(one[1]-1)+'\t'+str(one[1])+'\t'+one[2]+'\t'+one[3]+'\t'+one[4]+'\n')
	f1.close()
	f2.close()
	f3.close()
	fo.close()



def mask_zz2snv(zz_in_dir=0,bed_out_dir=0,baseq_cutoff_dir=0):


	fi=open(zz_in_dir)
	fo=open(bed_out_dir,'w')

	fqua=open(baseq_cutoff_dir)
	limitbasequa=int(fqua.readline().replace('\n',''))
	fqua.close()
	limitad=1
	limitloc=5
	limitmpqua=0
	allsnv={}
	for line in fi:
		truesnv=[]
		seq=line[0:-1].split('\t')
		mismatch=seq[4].split(';')
		basequa=seq[5].split(',')
		loc=seq[9].split(',') #fragment-loc
		mpqua=int(seq[2])
		####################################################################
 		#change the sam flag 'seq[1]' when you didn't use "bwa -aln" as mapper
		seq[1]=int(seq[1])
		if len(bin(seq[1]))>=7:
			if bin(seq[1])[-3]!='1':
				if bin(seq[1])[-5]=='1':
					seq[1]='16'
				else:
					seq[1]='0'
		elif len(bin(seq[1]))>=5:
			if bin(seq[1])[-3]!='1':
				seq[1]='0'
					 		
		else: 
			seq[1]='0'
		#####################################################################
	
		
		
		if basequa[0]!='*' and mpqua >= limitmpqua and mpqua < 200:


				



			tmp_snv=[]
			i=0
			while i < len(basequa):
				if int(basequa[i]) >= limitbasequa  and  int(loc[i]) > limitloc  :

					truesnv.append([mismatch[i],seq[1],seq[8]])
				if int(loc[i])>limitloc:
					tmp_snv.append(mismatch[i])
					
				i=i+1
			
			fflag=1
			if len(tmp_snv)>0:
				tag=tmp_snv[0].split(':')[0]
				#fflag=1
				for one in tmp_snv:
					if one.split(':')[0] != tag:
						fflag=0
				
			

			if fflag==1:
				for snv in truesnv:
				
					try:
						allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][0]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][0]+1
						if (snv[1]=='16' and snv[2][-1] == '1' ) or (snv[1]=='0' and snv[2][-1] == '2' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][1]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][1]+1
						elif (snv[1]=='16' and snv[2][-1] == '2' ) or (snv[1]=='0' and snv[2][-1] == '1' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][2]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][2]+1
					except Exception, e:
						if (snv[1]=='16' and snv[2][-1] == '1' ) or (snv[1]=='0' and snv[2][-1] == '2' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]]=[1,1,0]
						elif (snv[1]=='16' and snv[2][-1] == '2' ) or (snv[1]=='0' and snv[2][-1] == '1' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]]=[1,0,1]

	snv_bed=[]
	for snv in allsnv:
		seq=snv.split('\t')
		if allsnv[snv][0]>=limitad:
				if allsnv[snv][1] > allsnv[snv][2]: 
					snv_bed.append([seq[0],int(seq[2]),seq[1],'+',allsnv[snv][0]])
				elif allsnv[snv][2] > allsnv[snv][1]:
					snv_bed.append([seq[0],int(seq[2]),seq[1],'-',allsnv[snv][0]])
				else:
					snv_bed.append([seq[0],int(seq[2]),seq[1],'.',allsnv[snv][0]])

	snv_bed.sort()
	for one in snv_bed:
		fo.write(one[0]+'\t'+str(one[1]-1)+'\t'+str(one[1])+'\t'+one[2]+'\t'+str(one[4])+'\t'+one[3]+'\n')
	fi.close()
	fo.close()




import random
def random_select(file_in_dir=0,file_out_dir=0,ratio=1):


	fi=open(file_in_dir)
	fo=open(file_out_dir,'w')
	
	for line in fi:
		if random.random()<=ratio:
			fo.write(line)

	fi.close()
	fo.close()




def snv_cluster(bed_in_dir=0,bed_out_dir=0,cluster_distance=-1,cluster_size=-1):
	fi=open(bed_in_dir)
	fo=open(bed_out_dir,'w')
	tmp='chr0:0:AA'
	limitdistance=int(cluster_distance)
	limitnum=int(cluster_size)
	lst=[]
	for line in fi:
			seq=line.split('\t')
			tmpseq=tmp.split(':')
			if seq[0]==tmpseq[0] and int(seq[2])-int(tmpseq[1])<=limitdistance and seq[3]==tmpseq[2]:
				lst.append(line)
			else:
				if len(lst)>=limitnum:
						begin=float(lst[0].split('\t')[1])
						end=float(lst[-1].split('\t')[2])
						density=len(lst)/(end-begin)
						for one in lst:
							fo.write(one[0:-1]+'\t'+str(len(lst))+'\t'+str(density)+'\n')
				lst=[]
				lst.append(line)
			tmp=seq[0]+':'+seq[2]+':'+seq[3]
	if len(lst)>=limitnum:
			begin=float(lst[0].split('\t')[1])
			end=float(lst[-1].split('\t')[2])
			density=len(lst)/(end-begin)
			for one in lst:
				fo.write(one[0:-1]+'\t'+str(len(lst))+'\t'+str(density)+'\n')
	fi.close()
	fo.close()



def transcript_assembler(fref_in_dir=0, fgtf_in_dir=0, ftrans_out_dir=0):
    if fref_in_dir==0 or fgtf_in_dir==0:
        print 'fref_in_dir\tfgtf_in_dir\tftrans_out_dir'
        return 0








    fref=open(fref_in_dir)
    chrom={}
    chrr=''
    line=fref.read()
    line=line.split('>')
    for seq in line:
        if ' ' in seq:
            chrr=seq[0:seq.find(' ')]
        else:
            chrr=seq[0:seq.find('\n')]
        chrom[chrr]=seq[seq.find('\n'):].replace('\n','').upper()
    fref.close()





    #def antisense_reverse(read):
    #        read=read.upper()
    #        read_change_base=""   
    #        for one in read:
    #                if one == 'A':
    #                        read_change_base += 'T'
    #                elif one == 'C':
    #                        read_change_base += 'G'
    #                elif one == 'G':
    #                        read_change_base += 'C'
    #                elif one == 'T':
    #                        read_change_base += 'A'
    #                else:  
    #                        read_change_base += 'N'
    #        read_reverse=read_change_base[::-1]
    #        return read_reverse





    fgtf=open(fgtf_in_dir)
    transcript={}
    trc=[]

    for line in fgtf:
        if '#' != line[0]:
            seq=line.rstrip().split('\t')
            if seq[0] in chrom and seq[2]=='exon' and 'transcript_id ' in seq[8] and int(seq[4]) <= len(chrom[seq[0]]):
                chrr=seq[0]
                begin=int(seq[3])
                end=int(seq[4])
                transcript_id = seq[8].split('transcript_id ')[1].split(';')[0].replace('"','')
                strand = seq[6]
                if transcript_id not in transcript:
                    trc.append(transcript_id)
                    transcript[transcript_id] = [chrr,strand,[begin,end]]
                else:
                    transcript[transcript_id].append([begin,end])
    
    
    fgtf.close()


    ftrans=open(ftrans_out_dir,'w')
    ftransloc=open(ftrans_out_dir+'.loc','w')


    for transcript_id in trc:
        trans_name='>'+transcript_id+'_|_'+transcript[transcript_id][0]+'_|_'+transcript[transcript_id][1]+'\n'
        chrr=transcript[transcript_id][0]
        strand=transcript[transcript_id][1]
        loc=transcript[transcript_id][2:]
        trans_seq=''
        ftransloc.write(trans_name)
        for one in loc:
            ftransloc.write(str(one[0])+','+str(one[1])+';')
            trans_seq += chrom[chrr][one[0]-1:one[1]]
        ftransloc.write('\n')
        ftrans.write(trans_name)
        i=0
        while i < len(trans_seq):
            ftrans.write(trans_seq[i])
            i += 1
            if i%50==0:
                ftrans.write('\n')
        if i%50!=0:
            ftrans.write('\n')


















def cut(fq_in_dir=0,fq_out_dir=0,cutnum=6,name='read1'):
	fi=open(fq_in_dir)
	fo=open(fq_out_dir,'w')
	cutnum=int(cutnum)
	line1=fi.readline()
	line2=fi.readline()
	line3=fi.readline()
	line4=fi.readline()
	idd=1
	while line1 !='':
		fo.write('@id_'+str(idd)+'_'+name+'\n')
		fo.write(line2[cutnum:])
		fo.write(line3)
		fo.write(line4[cutnum:])
		line1=fi.readline()
		line2=fi.readline()
		line3=fi.readline()
		line4=fi.readline()
		idd=idd+1
	fi.close()
	fo.close()	



def o2b(bed_in,bed_out):
    fi=open(bed_in)
    fo=open(bed_out,'w')
    for line in fi:
        seq=line.rstrip().split('\t')
        #if float(seq[7])<0.2:
        fo.write('\t'.join(seq[0:6])+'\n')



from get_depth import *
from sam2zz import *
from zz2snv import *
from snv_cluster import *
from get_epm import *
from mask_zz2snv import *
from get_snv_with_ad import *
from combine_depth import *
from dedup import *
from get_res import *



def snv_or(bed_in_dir1,bed_in_dir2,bed_out_dir):
    f1=open(bed_in_dir1)
    f2=open(bed_in_dir2)
    fo=open(bed_out_dir,'w')
    whole={}
    for line in f1:
        seq=line.rstrip().split('\t')
        whole[':'.join(seq[0:4])+':'+seq[5]]=int(seq[4])
    for line in f2:
        seq=line.rstrip().split('\t')
        if ':'.join(seq[0:4])+':'+seq[5] in whole:
            whole[':'.join(seq[0:4])+':'+seq[5]] +=int(seq[4])
        else:
            whole[':'.join(seq[0:4])+':'+seq[5]]=int(seq[4])
    lst=[]
    for one in whole:
        seq=one.split(':')
        lst.append([seq[0],int(seq[1]),int(seq[2]),seq[3],str(whole[one]),seq[4]])
    lst.sort()
    for one in lst:
        out=[]
        for i in one:
            out.append(str(i))
        fo.write('\t'.join(out)+'\n')

    f1.close()
    f2.close()
    fo.close()



#[bwa_aln] 17bp reads: max_diff = 2
#[bwa_aln] 38bp reads: max_diff = 3
#[bwa_aln] 64bp reads: max_diff = 4
#[bwa_aln] 93bp reads: max_diff = 5
#[bwa_aln] 124bp reads: max_diff = 6
#[bwa_aln] 157bp reads: max_diff = 7
#[bwa_aln] 190bp reads: max_diff = 8
#[bwa_aln] 225bp reads: max_diff = 9



def mismatch_num(seqlen):
	if seqlen < 17:
		return 1
	elif seqlen <38:
		return 2
	elif seqlen <64:
		return 3
	elif seqlen <93:
		return 4
	elif seqlen <124:
		return 5
	elif seqlen <157:
		return 6
	elif seqlen <190:
		return 7
	elif seqlen <225:
		return 8
	else:
		return 9




def mask_zz2snv(zz_in_dir=0,bed_out_dir=0,baseq_cutoff_dir=0):

	
	fi=open(zz_in_dir)
	fo=open(bed_out_dir,'w')

	fqua=open(baseq_cutoff_dir)
	limitbasequa=int(fqua.readline().replace('\n',''))
	fqua.close()
	limitad=1
	limitloc=5
	limitmpqua=0
	allsnv={}
	for line in fi:
		truesnv=[]
		seq=line.rstrip().split('\t')
		mismatch=seq[4].split(';')
		basequa=seq[5].split(',')
		loc=seq[9].split(',') #fragment-loc
		mpqua=int(seq[2])
		####################################################################
 		#change the sam flag 'seq[1]' when you didn't use "bwa -aln" as mapper
		seq[1]=int(seq[1])
		if len(bin(seq[1]))>=7:
			if bin(seq[1])[-3]!='1':
				if bin(seq[1])[-5]=='1':
					seq[1]='16'
				else:
					seq[1]='0'
		elif len(bin(seq[1]))>=5:
			if bin(seq[1])[-3]!='1':
				seq[1]='0'
					 		
		else: 
			seq[1]='0'
		#####################################################################
	
		
		
		if basequa[0]!='*' and mpqua >= limitmpqua and mpqua < 200:
			i=0
			baseqlst=[]
			mistype={}
			while i < len(basequa):
				baseqlst.append(int(basequa[i]))
				try:
					mistype[mismatch[i].split(':')[0]] += 1
				except Exception , e:
					mistype[mismatch[i].split(':')[0]] = 1
				if int(basequa[i]) >= limitbasequa  and  int(loc[i]) > limitloc  :

					truesnv.append([mismatch[i],seq[1],seq[8]])
					
				i=i+1

			#fflag=1
			#masktype_tmp=seq[8].split('_|_')[1].split('_to_')
			#masktype=masktype_tmp[0]+masktype_tmp[1]
			miss=[]
			for mis in mistype:
				miss.append(mistype[mis])
			miss.sort()
			if len(miss)>=2:
				missnum=sum(miss[:-1])
			else:
				missnum=0
			


			
			if len(baseqlst)>0 and sum(baseqlst)/float(len(baseqlst)) >= limitbasequa: #and missnum <= mismatch_num(len(seq[7])):
				for snv in truesnv:
					try:
						allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][0]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][0]+1
						if (snv[1]=='16' and snv[2][-1] == '1' ) or (snv[1]=='0' and snv[2][-1] == '2' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][1]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][1]+1
						elif (snv[1]=='16' and snv[2][-1] == '2' ) or (snv[1]=='0' and snv[2][-1] == '1' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][2]=allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]][2]+1
					except Exception, e:
						if (snv[1]=='16' and snv[2][-1] == '1' ) or (snv[1]=='0' and snv[2][-1] == '2' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]]=[1,1,0]
						elif (snv[1]=='16' and snv[2][-1] == '2' ) or (snv[1]=='0' and snv[2][-1] == '1' ):
							allsnv[seq[0]+'\t'+snv[0].split(':')[0]+'\t'+snv[0].split(':')[1]]=[1,0,1]

	snv_bed=[]
	for snv in allsnv:
		seq=snv.split('\t')
		if allsnv[snv][0]>=limitad:
				if allsnv[snv][1] > allsnv[snv][2]: 
					snv_bed.append([seq[0],int(seq[2]),seq[1],'+',allsnv[snv][0]])
				elif allsnv[snv][2] > allsnv[snv][1]:
					snv_bed.append([seq[0],int(seq[2]),seq[1],'-',allsnv[snv][0]])
				else:
					snv_bed.append([seq[0],int(seq[2]),seq[1],'.',allsnv[snv][0]])

	snv_bed.sort()
	for one in snv_bed:
		fo.write(one[0]+'\t'+str(one[1]-1)+'\t'+str(one[1])+'\t'+one[2]+'\t'+str(one[4])+'\t'+one[3]+'\n')
	fi.close()
	fo.close()





def change_sam_read_name(sam_in_dir=0,sam_out_dir=0,name='read1'):
	fi=open(sam_in_dir)
	fo=open(sam_out_dir,'w')
	name=name
	idd=1
	for line in fi:
		if line[0] !='@':
			seq=line.split('\t')
			fo.write('id_'+str(idd)+'_'+name+line.replace(seq[0],''))
			idd=idd+1
		else:
			fo.write(line)
	fo.close()
	fi.close()



def transcript_sort(fbed_in_dir=0,fbed_out_dir=0):

    fi=open(fbed_in_dir)
    fo=open(fbed_out_dir,'w')

    whole={}
    for line in fi:
        seq=line.rstrip().split('\t')
        try:
            whole[seq[0]+':'+seq[2]+':'+seq[3]+':'+seq[5]] += int(seq[4])
        except Exception,e:
            whole[seq[0]+':'+seq[2]+':'+seq[3]+':'+seq[5]] = int(seq[4])

    tmp=[]
    for one in whole:
        seq=one.split(':')
        dep=str(whole[one])
        tmp.append([seq[0],int(seq[1]),seq[2],dep,seq[3]])
    tmp.sort()
    for one in tmp:
       fo.write(one[0]+'\t'+str(one[1]-1)+'\t'+str(one[1])+'\t'+one[2]+'\t'+one[3]+'\t'+one[4]+'\n')










def get_depth(zz_in_dir=0,bed_in_dir=0,bed_out_dir=0):

	fread=open(zz_in_dir)# './zz_folder/all.zz')
	fsnv=open(bed_in_dir) #'../bed_folder/try_new.bed') #   Hap_SRR521447.bed')
	fo=open(bed_out_dir,'w')#'./tmp/readspersite_new.zer','w')

	class Read:
		def __init__(self,read):
			
			self.snv=read.split('\t')[4].split(';')
			self.inter=read.split('\t')[3].split(';')
			self.direct=read.split('\t')[1]
		def locisin(self,loc):
			isin=0
			for inter in self.inter:
				inter=inter.split(':')
				if int(loc)<=int(inter[1]) and int(loc)>=int(inter[0]):
					isin =1
					break
			if isin ==0:
				return 0
			elif isin ==1:
				return 1
		def snvisin(self,snv):
			if snv in self.snv:
				return 1
			else:
				return 0
		def getmin(self):
			return int(self.inter[0].split(':')[0])
		def getmax(self):
			return int(self.inter[-1].split(':')[1])


	reads={}
	for line in fread:
		seq=line.split('\t')
		try:
				reads[seq[0]].append(line[0:-1])
		except Exception,e :
				#print seq[0]+' begin'
				reads[seq[0]]=[line[0:-1]]


	top=0
	chrr=''
	for line in fsnv:
		seq=line[0:-1].split('\t')
		deep=0
		altdeep=0
		snv=seq[3]+':'+seq[2]
		if seq[0] != chrr:
			top=0
			chrr=seq[0]
		if seq[0] not in reads:
			reads[seq[0]]=[]
		if top < len(reads[seq[0]]):
			while seq[0]==chrr and top < len(reads[seq[0]]) and Read(reads[seq[0]][top]).getmax() < int(seq[2]):
				top=top+1
			point=top
			while seq[0]==chrr and point < len(reads[seq[0]]) and Read(reads[seq[0]][point]).getmin() <= int(seq[2]):
				if Read(reads[seq[0]][point]).locisin(seq[2]) ==1:
					deep=deep+1
					
				if Read(reads[seq[0]][point]).snvisin(snv)==1:
					altdeep=altdeep+1
				
				point=point+1
		fo.write(line[0:-1]+'\t'+str(altdeep)+':'+str(deep)+'\n')
		
	fread.close()
	fsnv.close()
	fo.close()




def hyper_or(bed_in_dir1,bed_in_dir2,bed_out_dir):
	f1=open(bed_in_dir1)
	f2=open(bed_in_dir2)
	fo=open(bed_out_dir,'w')
	whole=[]
	for line in f1:
		seq=line.replace('\n','').split('\t')
		whole.append([seq[0],int(seq[2]),seq[3],seq[-1],seq[5]])
	for line in f2:
		seq=line.replace('\n','').split('\t')
		whole.append([seq[0],int(seq[2]),seq[3],seq[-1],seq[5]])
	whole.sort()
	old=set()
	for one in whole:
		if one[0]+':'+str(one[1]) not in old:
			fo.write(one[0]+'\t'+str(one[1]-1)+'\t'+str(one[1])+'\t'+one[2]+'\t'+one[3]+'\t'+one[4]+'\n')
			old.add(one[0]+':'+str(one[1]))
	f1.close()
	f2.close()
	fo.close()



#import sprint
def pipeline():
    import re,sys
    from sprint_prepare import prepare as PP
    from sprint_main import main as MA



    def help_doc():


        print ''
        print "##############################################################################################"
        print ''
        print "   SPRINT: SNP-free RNA editing Identification Toolkit"
        print ""
        print "   http://sprint.tianlab.cn/SPRINT/"
        print ""
        print "   Please contact with 15110700005@fudan.edu.cn when questions arise."
        print ""
        print "##############################################################################################"
        print ""
        print ""
        print '   Usage: '
        print ""
        print '      "sprint prepare" or "sprint pp"   #build mapping index'
        print ""
        print '      "sprint main" or "sprint ma"      #identify RESs'
        print ""
        print ""
        sys.exit(0)

    if len(sys.argv)<2:
        help_doc()

    if sys.argv[1] =='sprint_prepare' or sys.argv[1] =='prepare' or sys.argv[1] =='pp'  :
        sys.argv=sys.argv[1:]
        PP()

    elif sys.argv[1]=='sprint_main' or sys.argv[1]=='main' or sys.argv[1] =='ma':
        sys.argv=sys.argv[1:]
        MA()
    else:
        #print sys.argv[2]
        help_doc()




def maskTwithC(fa_in_dir=0,fa_out_dir=0):
    if fa_in_dir==0 or fa_out_dir==0:
        print 'fa_in_dir\tfa_our_dir'
        return 0
    fi=open(fa_in_dir)
    fo=open(fa_out_dir,'w')

    for line in fi:
        if line[0]=='>':
            fo.write(line)
        else:
            fo.write(line.replace('T','C').replace('t','c'))




#poly_limit=10

def poly_check(seq,poly_limit):
	if 'A'*poly_limit not in seq and 'T'*poly_limit not in seq and 'G'*poly_limit not in seq and 'C'*poly_limit not in seq:
		return True
	else:
		return False
				
def var_check(change_from, change_to, seq,var_limit):
	ALL=['A','T','C','G']
	tmp=[]
	for one in ALL:
		if one !=change_from.upper() and one !=change_to.upper():
			tmp.append(one)
	flag=1
	for one in tmp:
		if seq.count(one) < var_limit/(float(len(tmp))+1):
			flag=0
	if flag==1:
		return True
	else:
		return False
	
def reverse_base(base):
	base=base.upper()
	if base=='A':
		return 'T'
	elif base=='C':
		return 'G'
	elif base=='G':
		return 'C'
	elif base=='T':
		return 'A'
	else:
		return 'N'		
def recover_sam(sam_in_dir,sam_out_dir, var_limit=20,poly_limit=10,rm_multi=0):

	fi=open(sam_in_dir)
	fo=open(sam_out_dir,'w')
	for line in fi:
		seq=line.split('\t')
		if line[0]=='@':
			fo.write(line)
		elif seq[1]=='4' and seq[2]=='*':
			break
		elif seq[1]!='4' and len(seq)>=9:
			seq=line.split('\t')
			seq[9]=seq[9].upper()
			seq[1]=int(seq[1])
			if len(bin(seq[1]))>=7:
				if bin(seq[1])[-3]!='1':
					if bin(seq[1])[-5]=='1':
						seq[1]='16'
					else:
						seq[1]='0'
			seq[1]=str(seq[1])
			record=bin(int(seq[0].split('_|_')[2]))[3:]
			change_from=seq[0].split('_|_')[1].split('_')[0]
			change_to=seq[0].split('_|_')[1].split('_')[2]
			
			
			if seq[1]=='16':
				change_from=reverse_base(change_from)
				change_to=reverse_base(change_to)
				record=record[::-1]
			else:
				record=record
			changed_read=seq[9]
			i=0
			recovered_read=''
			while i<len(seq[9]):
				if record[i]=='1' and seq[9][i]==change_to:
					recovered_read += change_from
				elif record[i]=='1' and seq[9][i]!=change_to:
					#print "recover error in "+seq[0]
					recovered_read += 'N'
				else:
					recovered_read += seq[9][i]
				i=i+1
			seq[9]=recovered_read
			#fo.write(seq[0])
			#if len(record)==len(seq[9]) and 'I' not in seq[5] and 'D' not in seq[5] and len(record)-changed_read.count(change_to) > 25 and poly_check(seq[9],poly_limit):
			if len(record)==len(seq[9]) and len(record)-changed_read.count(change_to) > var_limit and poly_check(seq[9],poly_limit): #and var_check(change_from,change_to,seq[9],var_limit):
				if (rm_multi==1 and "XA:Z:" not in line) or rm_multi==0:
					fo.write(seq[0])
					j=1
					while j<len(seq):
			
						fo.write('\t'+seq[j])
						j=j+1
			
			#		1+1
	fo.close()
	fi.close()




def get_epm(bed_in_dir,epm_out_dir,flag,zz_in_dir):
	fi=open(bed_in_dir)
	fo=open(epm_out_dir,'w')
	fread=open(zz_in_dir)
	gene={}
	for line in fi:
		seq=line.replace('\n','').split('\t')
		i=0
		while i< len(seq):
			if flag in seq[i]:
				try:
					gene[seq[i]][0]=gene[seq[i]][0]+int(seq[4].split(':')[0])
					gene[seq[i]][1]=gene[seq[i]][1]+1
					#gene[seq[i]].append(int(seq[2]))
			
				except Exception, e:
					gene[seq[i]]=[int(seq[4].split(':')[0]),1]

			i=i+1
	j=0
	for line in fread:
		j=j+1
	read_count=j

	read_million=float(read_count)/1000000
	
	for one in gene:
		'''
		tmp=1
		last=1
		point=2
		range_dis=0
		while point < len(gene[one]):
			if gene[one][point]-gene[one][last]>1000:
				range_dis=range_dis+tmp
				#last=point
				tmp=1
				
			else:
				tmp=tmp+gene[one][point]-gene[one][last]
				#last=point
			
			last=point
			point=point+1
		range_dis=range_dis+tmp
		'''
		epm=float(gene[one][0])/( read_million     )
		fo.write(one+'\t'+str(epm)+'\t'+str(gene[one][0])+'\t'+str(gene[one][1])+'\n')

	fi.close()
	fo.close()
	fread.close()



def bed_sort(bed_in_dir,bed_out_dir):
	fi=open(bed_in_dir)
	fo=open(bed_out_dir,'w')
	whole=[]
	for line in fi:
		seq=line.split('\t')
		whole.append([seq[0],int(seq[1]),int(seq[2]),line])	
	whole.sort()
	for one in whole:
		fo.write(one[3])
	fi.close()
	fo.close()



def antisense_reverse(read):
	read=read.upper()
	read_change_base=""
	for one in read:
		if one == 'A':
			read_change_base += 'T'
		elif one == 'C':
			read_change_base += 'G'
		elif one == 'G':
			read_change_base += 'C'
		elif one == 'T':
			read_change_base += 'A'
		else:
			read_change_base += 'N'
	read_reverse=read_change_base[::-1]
	return read_reverse


def maskfq(fq_in_dir,mask_from,mask_to):
	mask_from=mask_from.upper()
	mask_to=mask_to.upper()
	fi=open(fq_in_dir)
	fo=open(fq_in_dir[0:-3]+'_'+mask_from+'_to_'+mask_to+'.fq','w')
	line1=fi.readline().replace('\n','')
	line2=fi.readline().upper().replace('\n','')
	line3=fi.readline().replace('\n','')
	line4=fi.readline().replace('\n','')
	while line1 !='':
		if line1[-1]=='1':
			line2=antisense_reverse(line2)
			line4=line4[::-1]
		record="1"
		line2_new=""
		for one in line2.replace('\n',''):
			if one==mask_from:
				record=record+'1'
			else:
				record=record+'0'
		
		fo.write(line1+'_|_'+mask_from+'_to_'+mask_to+'_|_'+str(int(record,2))+'_|_read2'+'\n')
		fo.write(line2.replace(mask_from,mask_to)+'\n')			
		fo.write('+\n')
		fo.write(line4+'\n')
		line1=fi.readline().replace('\n','')
		line2=fi.readline().upper().replace('\n','')
		line3=fi.readline().replace('\n','')
		line4=fi.readline().replace('\n','')
	fi.close()
	fo.close()




def get_res(regular_alu,regular_nalurp,regular_nrp,hyper,output):

    falu=open(regular_alu)
    fnalurp=open(regular_nalurp)
    fnrp=open(regular_nrp)
    fhyper=open(hyper)
    fo_AI=open(output+'_A_to_I_regular.res','w')
    fo_hAI=open(output+'_A_to_I_hyper.res','w')
    fo_CU=open(output+'_C_to_U.res','w')

    for line in falu:
        seq=line.rstrip().split('\t')
        if seq[3]=='AG' or seq[3]=='TC':
            fo_AI.write(line)
    for line in fnalurp:
        seq=line.rstrip().split('\t')
        if seq[3]=='AG' or seq[3]=='TC':
            fo_AI.write(line)
        if seq[3]=='CT' or seq[3]=='GA':
            fo_CU.write(line)
    for line in fnrp:
        seq=line.rstrip().split('\t')
        if seq[3]=='AG' or seq[3]=='TC':
            fo_AI.write(line)
        if seq[3]=='CT' or seq[3]=='GA':
            fo_CU.write(line)
    for line in fhyper:
        seq=line.rstrip().split('\t')
        if seq[3]=='AG' or seq[3]=='TC':
            fo_hAI.write(line)



import subprocess,sprint,os,sys

def main(): 
    import subprocess,sprint,os,sys
    print ''
    print "##############################################################################################"
    print ''
    print "   SPRINT: SNP-free RNA editing Identification Toolkit"
    print ""
    print "   http://sprint.tianlab.cn/SPRINT/"
    print ""
    print "   Please contact with 15110700005@fudan.edu.cn when questions arise."
    print ""
    print "##############################################################################################"
    
    
    def help_doc():
        print ""
        print "   Attention:"
        print ""
        print "      Before using sprint_main, please use sprint_prepare to build mapping index."
        print ""
        print "   Usage:"
        print ""
        print "      sprint main   [options]   read(.fq)   reference_genome(.fa)   output_path   bwa_path   samtools_path"
        print ""
        print "      options:"
        print "         -rp repeat_file #Download from http://sprint.software/SPRINT/dbrep/"
        print "         -2  read2(.fq)  #Optional"
        print "         -c  INT         #Remove the fist INT bp in reads (default is 6)"
        print "         -p  INT         #Mapping CPU (default is 1)"
        print ""
        print "   Example:"
        print ""
        print "       sprint main -rp hg19_repeat.txt -c 6 -p 6 -2 read2.fq read1.fq hg19.fa output ./bwa-0.7.12/bwa ./samtools-1.2/samtools"
        print ""
        print ""
        print ""
        #print sys.argv[0]
        
        sys.exit(0)
    
    
    if len(sys.argv)<2:
        #print sys.argv[0]
        help_doc()
    
    
    
    cutbp=6
    cluster_distance=200
    mapcpu = 1
    
    
    paired_end=False
    repeat=False
    options=[]
    read2=''
    #print sys.argv
    i=1
    while i< len(sys.argv):
        if sys.argv[i]=='-2':
            paired_end=True
            try:
                read2=sys.argv[i+1]
                options.append(i)
                options.append(i+1)
            except Exception, e:
                print 'options error!'
                help_doc()
                exit()
        elif sys.argv[i]=='-rp':
            try:
                repeat=sys.argv[i+1]
                options.append(i)
                options.append(i+1)
            except Exception, e:
                print 'options error!'
                help_doc()
                exit()
        elif sys.argv[i]=='-c':
            try:
                cutbp=int(sys.argv[i+1])
                options.append(i)
                options.append(i+1)
            except Exception, e:
                print 'options error!'
                help_doc()
                exit()
        elif sys.argv[i]=='-p':
            try:
                mapcpu=int(sys.argv[i+1])
                options.append(i)
                options.append(i+1)
            except Exception, e:
                print 'options error!'
                help_doc()
                exit()
    
    
        i += 1
    
    all_argv=[]
    i=1
    while i< len(sys.argv):
        if i not in options:
            all_argv.append(i)
        i=i+1
    
    if len(all_argv)!=5:
        help_doc()
        exit()
    
    
    read1=sys.argv[all_argv[0]]
    refgenome=sys.argv[all_argv[1]]
    output=sys.argv[all_argv[2]]+'/'
    tmp=output+'/tmp/'
    #if output[-1]!='/':
    #    tmp=output+'.tmp/'
    #else:
    #    tmp=output[:-1]+'.tmp/'
    bwa=sys.argv[all_argv[3]]
    samtools=sys.argv[all_argv[4]]
    
    if os.path.exists(output)==False:
            os.mkdir(output)
    if os.path.exists(tmp)==False:
            os.mkdir(tmp)
    
    #if paired_end==True:
    #    mapcpu=max([int(int(mapcpu)/2.0),1])
    
    
    
    
    
    def fq2sam(TAG,paired_end,read1,read2,tmp,refgenome,bwa,samtools,mapcpu):
        if paired_end==True:
            mapcpu=max([int(int(mapcpu)/2.0),1])
        ori_tmp=tmp
        tmp=tmp+'/'+TAG+'/'
        if os.path.exists(tmp)==False:
            os.mkdir(tmp)
        step1_1=subprocess.Popen(bwa+' aln -t '+str(mapcpu)+' '+refgenome+' '+read1+' > '+tmp+'read1.sai',shell=True)
        if paired_end==True:
            step1_2=subprocess.Popen(bwa+' aln -t '+str(mapcpu)+' '+refgenome+' '+read2+' > '+tmp+'read2.sai',shell=True)
        step1_1.wait()
        if paired_end==True:
            step1_2.wait()
        step1_3=subprocess.Popen(bwa+' samse -n4 '+refgenome+' '+tmp+'read1.sai '+read1+' > '+tmp+'name_read1.sam',shell=True)
        if paired_end==True:
            step1_4=subprocess.Popen(bwa+' samse -n4 '+refgenome+' '+tmp+'read2.sai '+read2+' > '+tmp+'name_read2.sam',shell=True)
        step1_3.wait()
        if paired_end==True:
            step1_4.wait()
        if os.path.exists(tmp+'name_read1.sam'):
            if os.path.exists(tmp+'read1.sai'):
                    os.remove(tmp+'read1.sai')
            if os.path.exists(ori_tmp+'cut_read1.fastq'):
                    os.remove(ori_tmp+'cut_read1.fastq')
        if os.path.exists(tmp+'name_read2.sam'):
            if os.path.exists(tmp+'read2.sai'):
                    os.remove(tmp+'read2.sai')
            if os.path.exists(ori_tmp+'cut_read2.fastq'):
                    os.remove(ori_tmp+'cut_read2.fastq')
    
        #sprint.change_sam_read_name(tmp+'read1.sam',tmp+'name_read1.sam','read1')
        #if paired_end==True:
        #    sprint.change_sam_read_name(tmp+'read2.sam',tmp+'name_read2.sam','read2')
        step1_7=subprocess.Popen(samtools+' view -bS '+tmp+'name_read1.sam >'+tmp+'name_read1.bam',shell=True)
        if paired_end==True:
            step1_8=subprocess.Popen(samtools+' view -bS '+tmp+'name_read2.sam >'+tmp+'name_read2.bam',shell=True)
        step1_7.wait()
        if paired_end==True:
            step1_8.wait()
        if paired_end==True:
            step1_9=subprocess.Popen(samtools+' sort '+tmp+'name_read1.bam '+tmp+'name_read1_sorted',shell=True)
            step1_10=subprocess.Popen(samtools+' sort '+tmp+'name_read2.bam '+tmp+'name_read2_sorted',shell=True)
            step1_9.wait()
            step1_10.wait()
            step1_11=subprocess.Popen(samtools+' merge -f '+tmp+'all.bam '+tmp+'name_read1_sorted.bam '+tmp+'name_read2_sorted.bam',shell=True)
            step1_11.wait()
            if os.path.exists(tmp+'all.bam'):
                    if os.path.exists(tmp+'name_read1.sam'):
                            os.remove(tmp+'name_read1.sam')
                    if os.path.exists(tmp+'name_read1.bam'):
                            os.remove(tmp+'name_read1.bam')
                    if os.path.exists(tmp+'name_read1_sorted.bam'):
                            os.remove(tmp+'name_read1_sorted.bam')
                    if os.path.exists(tmp+'name_read2.sam'):
                            os.remove(tmp+'name_read2.sam')
                    if os.path.exists(tmp+'name_read2.bam'):
                            os.remove(tmp+'name_read2.bam')
                    if os.path.exists(tmp+'name_read2_sorted.bam'):
                            os.remove(tmp+'name_read2_sorted.bam')
    
        else:
            step1_9=subprocess.Popen(samtools+' sort '+tmp+'name_read1.bam '+tmp+'all',shell=True)
            step1_9.wait()
            if os.path.exists(tmp+'all.bam'):
                    if os.path.exists(tmp+'name_read1.sam'):
                            os.remove(tmp+'name_read1.sam')
                    if os.path.exists(tmp+'name_read1.bam'):
                            os.remove(tmp+'name_read1.bam')
        step2_2=subprocess.Popen(samtools+' view -h -o '+tmp+'all.sam '+tmp+'all.bam',shell=True)
        step2_2.wait()
        subprocess.Popen('cp '+tmp+'./all.sam '+ori_tmp+'/'+TAG+'_all.sam',shell=True).wait()
        if os.path.exists(tmp+'all.sam'):
            #os.remove(tmp+'all.bam')
            os.remove(tmp+'all.sam')
            #try:
            #    os.rmdir(tmp)
            #except Exception,e:
            #    pass
    
    
      
    
    
    
    
    try:
    #if 1==1:
        
        sprint.cut(read1,tmp+'cut_read1.fastq',cutbp,'read1')
        if paired_end==True:
            sprint.cut(read2,tmp+'cut_read2.fastq',cutbp,'read2')
        sprint.get_baseq_cutoff(read1,tmp+'baseq.cutoff')
        
    
        TAG='genome'
        fq2sam(TAG,paired_end,tmp+'cut_read1.fastq',tmp+'cut_read2.fastq',tmp,refgenome,bwa,samtools,mapcpu)
    
        subprocess.Popen(samtools+' view -f4 '+tmp+'/'+TAG+'/all.bam > '+tmp+'/'+TAG+'_unmapped.sam',shell=True).wait()
        sprint.umsam2fq(tmp+'/'+TAG+'_unmapped.sam',tmp+'/'+TAG+'_unmapped.fq')
     
        if os.path.exists(refgenome+'.trans.fa'):
            TAG='transcript'
            fq2sam(TAG,False,tmp+'/genome_unmapped.fq',read2,tmp,refgenome+'.trans.fa',bwa,samtools,mapcpu)
    
            subprocess.Popen(samtools+' view -f4 '+tmp+'/'+TAG+'/all.bam > '+tmp+'/'+TAG+'_unmapped.sam',shell=True).wait()
            sprint.umsam2fq(tmp+'/'+TAG+'_unmapped.sam',tmp+'/regular_unmapped.fq')    
            sprint.maskfq(tmp+'/regular_unmapped.fq','A','G')
        else:
            sprint.umsam2fq(tmp+'/'+TAG+'_unmapped.sam',tmp+'/regular_unmapped.fq')
            sprint.maskfq(tmp+'/regular_unmapped.fq','A','G')
    
    
        TAG='genome_mskAG'
        fq2sam(TAG,False,tmp+'/regular_unmapped_A_to_G.fq',read2,tmp,refgenome+'.mskAG.fa',bwa,samtools,mapcpu)
    
        subprocess.Popen(samtools+' view -f4 '+tmp+'/'+TAG+'/all.bam > '+tmp+'/'+TAG+'_unmapped.sam',shell=True).wait()
        sprint.umsam2fq(tmp+'/'+TAG+'_unmapped.sam',tmp+'/'+TAG+'_unmapped.fq')    
    
        TAG='genome_mskTC'
        fq2sam(TAG,False,tmp+'/regular_unmapped_A_to_G.fq',read2,tmp,refgenome+'.mskTC.fa',bwa,samtools,mapcpu)
    
        subprocess.Popen(samtools+' view -f4 '+tmp+'/'+TAG+'/all.bam > '+tmp+'/'+TAG+'_unmapped.sam',shell=True).wait()
        sprint.umsam2fq(tmp+'/'+TAG+'_unmapped.sam',tmp+'/'+TAG+'_unmapped.fq')    
        
        
        if os.path.exists(refgenome+'.trans.fa'):
            TAG='transcript_mskAG'
            fq2sam(TAG,False,tmp+'/genome_mskAG_unmapped.fq',read2,tmp,refgenome+'.trans.fa.mskAG.fa',bwa,samtools,mapcpu)
    
            TAG='transcript_mskTC'
            fq2sam(TAG,False,tmp+'/genome_mskTC_unmapped.fq',read2,tmp,refgenome+'.trans.fa.mskTC.fa',bwa,samtools,mapcpu)
    
        if os.path.exists(tmp+'genome_mskAG_unmapped.sam'):
                    if os.path.exists(tmp+'cut_read1.fastq'):
                            os.remove(tmp+'cut_read1.fastq')
                    if os.path.exists(tmp+'cut_read2.fastq'):
                            os.remove(tmp+'cut_read2.fastq')
                    if os.path.exists(tmp+'genome_mskAG_unmapped.fq'):
                            os.remove(tmp+'genome_mskAG_unmapped.fq')
                    if os.path.exists(tmp+'genome_mskAG_unmapped.sam'):
                            os.remove(tmp+'genome_mskAG_unmapped.sam')
                    if os.path.exists(tmp+'genome_mskTC_unmapped.fq'):
                            os.remove(tmp+'genome_mskTC_unmapped.fq')
                    if os.path.exists(tmp+'genome_mskTC_unmapped.sam'):
                            os.remove(tmp+'genome_mskTC_unmapped.sam')
                    if os.path.exists(tmp+'genome_unmapped.fq'):
                            os.remove(tmp+'genome_unmapped.fq')
                    if os.path.exists(tmp+'genome_unmapped.sam'):
                            os.remove(tmp+'genome_unmapped.sam')
                    if os.path.exists(tmp+'transcript_unmapped_A_to_G.fq'):
                            os.remove(tmp+'transcript_unmapped_A_to_G.fq')
                    if os.path.exists(tmp+'transcript_unmapped.fq'):
                            os.remove(tmp+'transcript_unmapped.fq')
                    if os.path.exists(tmp+'transcript_unmapped.sam'):
                            os.remove(tmp+'transcript_unmapped.sam')
                    if os.path.exists(tmp+'regular_unmapped.fq'):
                            os.remove(tmp+'regular_unmapped.fq')
                    if os.path.exists(tmp+'regular_unmapped_A_to_G.fq'):
                            os.remove(tmp+'regular_unmapped_A_to_G.fq')
                            
        
        if os.path.exists(refgenome+'.trans.fa'):
            sprint.recover_sam(tmp+'transcript_mskAG_all.sam',tmp+'transcript_mskAG_all.sam.rcv')
            sprint.sam2zz(tmp+'transcript_mskAG_all.sam.rcv',refgenome+'.trans.fa',tmp+'transcript_mskAG_all.zz')
            sprint.recover_sam(tmp+'transcript_mskTC_all.sam',tmp+'transcript_mskTC_all.sam.rcv')
            sprint.sam2zz(tmp+'transcript_mskTC_all.sam.rcv',refgenome+'.trans.fa',tmp+'transcript_mskTC_all.zz')
            sprint.sam2zz(tmp+'transcript_all.sam',refgenome+'.trans.fa',tmp+'transcript_all.zz')
            
            if os.path.exists(tmp+'transcript_mskAG_all.sam.rcv'):
                os.remove(tmp+'transcript_mskAG_all.sam.rcv')
            if os.path.exists(tmp+'transcript_mskAG_all.sam'):
                os.remove(tmp+'transcript_mskAG_all.sam')
            if os.path.exists(tmp+'transcript_mskTC_all.sam.rcv'):
                os.remove(tmp+'transcript_mskTC_all.sam.rcv')
            if os.path.exists(tmp+'transcript_mskTC_all.sam'):
                os.remove(tmp+'transcript_mskTC_all.sam')
            if os.path.exists(tmp+'transcript_all.sam'):
                os.remove(tmp+'transcript_all.sam')

    
        sprint.recover_sam(tmp+'genome_mskAG_all.sam',tmp+'genome_mskAG_all.sam.rcv')
        sprint.sam2zz(tmp+'genome_mskAG_all.sam.rcv',refgenome,tmp+'genome_mskAG_all.zz')
        sprint.recover_sam(tmp+'genome_mskTC_all.sam',tmp+'genome_mskTC_all.sam.rcv')
        sprint.sam2zz(tmp+'genome_mskTC_all.sam.rcv',refgenome,tmp+'genome_mskTC_all.zz')
        sprint.sam2zz(tmp+'genome_all.sam',refgenome,tmp+'genome_all.zz')

        if os.path.exists(tmp+'genome_mskAG_all.sam.rcv'):
                os.remove(tmp+'genome_mskAG_all.sam.rcv')
        if os.path.exists(tmp+'genome_mskAG_all.sam'):
                os.remove(tmp+'genome_mskAG_all.sam')
        if os.path.exists(tmp+'genome_mskTC_all.sam.rcv'):
                os.remove(tmp+'genome_mskTC_all.sam.rcv')
        if os.path.exists(tmp+'genome_mskTC_all.sam'):
                os.remove(tmp+'genome_mskTC_all.sam')
        if os.path.exists(tmp+'genome_all.sam'):
                os.remove(tmp+'genome_all.sam')
                
        
        if os.path.exists(refgenome+'.trans.fa'):
            sprint.dedup(tmp+'transcript_mskAG_all.zz',tmp+'transcript_mskAG_all.zz.dedup')
            sprint.dedup(tmp+'transcript_mskTC_all.zz',tmp+'transcript_mskTC_all.zz.dedup') 
            sprint.dedup(tmp+'transcript_all.zz',tmp+'transcript_all.zz.dedup') 
    
        sprint.dedup(tmp+'genome_mskAG_all.zz',tmp+'genome_mskAG_all.zz.dedup') 
        sprint.dedup(tmp+'genome_mskTC_all.zz',tmp+'genome_mskTC_all.zz.dedup') 
        sprint.dedup(tmp+'genome_all.zz',tmp+'genome_all.zz.dedup')
         
        if os.path.exists(tmp+'transcript_mskAG_all.zz'):
                os.remove(tmp+'transcript_mskAG_all.zz')
        if os.path.exists(tmp+'transcript_mskTC_all.zz'):
                os.remove(tmp+'transcript_mskTC_all.zz')
        if os.path.exists(tmp+'transcript_all.zz'):
                os.remove(tmp+'transcript_all.zz')
        if os.path.exists(tmp+'genome_mskAG_all.zz'):
                os.remove(tmp+'genome_mskAG_all.zz')
        if os.path.exists(tmp+'genome_mskTC_all.zz'):
                os.remove(tmp+'genome_mskTC_all.zz')
        if os.path.exists(tmp+'genome_all.zz'):
                os.remove(tmp+'genome_all.zz')
    
   
        if os.path.exists(refgenome+'.trans.fa'):
            sprint.mask_zz2snv(tmp+'transcript_mskAG_all.zz.dedup',tmp+'transcript_mskAG_all.zz.dedup.snv',tmp+'baseq.cutoff') 
            sprint.mask_zz2snv(tmp+'transcript_mskTC_all.zz.dedup',tmp+'transcript_mskTC_all.zz.dedup.snv',tmp+'baseq.cutoff') 
            sprint.mask_zz2snv(tmp+'transcript_all.zz.dedup',tmp+'transcript_all.zz.dedup.snv',tmp+'baseq.cutoff') 
    
        sprint.mask_zz2snv(tmp+'genome_mskAG_all.zz.dedup',tmp+'genome_mskAG_all.zz.dedup.snv',tmp+'baseq.cutoff') 
        sprint.mask_zz2snv(tmp+'genome_mskTC_all.zz.dedup',tmp+'genome_mskTC_all.zz.dedup.snv',tmp+'baseq.cutoff') 
        sprint.mask_zz2snv(tmp+'genome_all.zz.dedup',tmp+'genome_all.zz.dedup.snv',tmp+'baseq.cutoff') 


        
        
     
        if os.path.exists(refgenome+'.trans.fa'):
            sprint.transcript_locator(tmp+'transcript_mskAG_all.zz.dedup.snv',refgenome+'.trans.fa.loc', tmp+'transcript_mskAG_all.zz.dedup.snv.genome.snv')
            sprint.transcript_locator(tmp+'transcript_mskTC_all.zz.dedup.snv',refgenome+'.trans.fa.loc', tmp+'transcript_mskTC_all.zz.dedup.snv.genome.snv')
            sprint.transcript_locator(tmp+'transcript_all.zz.dedup.snv',refgenome+'.trans.fa.loc', tmp+'transcript_all.zz.dedup.snv.genome.snv')

            sprint.transcript_sort(tmp+'transcript_all.zz.dedup.snv.genome.snv',tmp+'transcript_all.zz.dedup.snv.genome.snv.sort')
            sprint.transcript_sort(tmp+'transcript_mskTC_all.zz.dedup.snv.genome.snv',tmp+'transcript_mskTC_all.zz.dedup.snv.genome.snv.sort')
            sprint.transcript_sort(tmp+'transcript_mskAG_all.zz.dedup.snv.genome.snv',tmp+'transcript_mskAG_all.zz.dedup.snv.genome.snv.sort')

            sprint.snv_or(tmp+'transcript_all.zz.dedup.snv.genome.snv.sort',tmp+'genome_all.zz.dedup.snv',tmp+'regular.snv')
            sprint.snv_or(tmp+'transcript_mskTC_all.zz.dedup.snv.genome.snv.sort',tmp+'genome_mskTC_all.zz.dedup.snv', tmp+'hyper_mskTC.snv')
            sprint.snv_or(tmp+'transcript_mskAG_all.zz.dedup.snv.genome.snv.sort',tmp+'genome_mskAG_all.zz.dedup.snv', tmp+'hyper_mskAG.snv')

            #sprint.snv_or(tmp+'transcript_mskTC_all.zz.dedup.snv.genome.snv',tmp+'transcript_mskAG_all.zz.dedup.snv.genome.snv',tmp+'transcript_hyper.snv')
            #sprint.snv_or(tmp+'genome_mskTC_all.zz.dedup.snv',tmp+'genome_mskAG_all.zz.dedup.snv',tmp+'genome_hyper.snv')
            #sprint.snv_or(tmp+'transcript_hyper.snv',tmp+'genome_hyper.snv',tmp+'hyper.snv')

        else:
            subprocess.Popen('cp '+tmp+'/genome_all.zz.dedup.snv '+tmp+'/regular.snv',shell=True).wait()
            subprocess.Popen('cp '+tmp+'/genome_mskTC_all.zz.dedup.snv '+tmp+'/hyper_mskTC.snv',shell=True).wait()
            subprocess.Popen('cp '+tmp+'/genome_mskAG_all.zz.dedup.snv '+tmp+'/hyper_mskAG.snv',shell=True).wait()
            #sprint.snv_or(tmp+'genome_mskTC_all.zz.dedup.snv',tmp+'genome_mskAG_all.zz.dedup.snv',tmp+'/hyper.snv')
        
        if repeat !=False:
            sprint.annotate(tmp+'regular.snv',repeat,tmp+'regular.snv.anno')    
            sprint.seperate(tmp+'regular.snv.anno',tmp+'regular.snv.anno.alu',tmp+'regular.snv.anno.nalurp',tmp+'regular.snv.anno.nrp','Alu')
            sprint.get_snv_with_ad(tmp+'regular.snv.anno.alu',tmp+'regular.snv.anno.alu.ad2',2)
            sprint.snv_cluster(tmp+'regular.snv.anno.alu',tmp+'regular_alu.res.ad1',cluster_distance,3)
            sprint.snv_cluster(tmp+'regular.snv.anno.alu.ad2',tmp+'regular_alu.res.ad2',cluster_distance,2)
            sprint.bed_or(tmp+'regular_alu.res.ad1',tmp+'regular_alu.res.ad2',tmp+'regular_alu.res')
            sprint.snv_cluster(tmp+'regular.snv.anno.nalurp',tmp+'regular_nalurp.res',cluster_distance,5)
            sprint.snv_cluster(tmp+'regular.snv.anno.nrp',tmp+'regular_nrp.res',cluster_distance,7)
            sprint.combine_res(tmp+'regular_alu.res',tmp+'regular_nalurp.res',tmp+'regular_nrp.res',tmp+'regular.res')
    
            sprint.annotate(tmp+'hyper_mskTC.snv',repeat,tmp+'hyper_mskTC.snv.anno')    
            sprint.seperate(tmp+'hyper_mskTC.snv.anno',tmp+'hyper_mskTC.snv.anno.alu',tmp+'hyper_mskTC.snv.anno.nalurp',tmp+'hyper_mskTC.snv.anno.nrp','Alu')
            sprint.combine_res(tmp+'hyper_mskTC.snv.anno.alu',tmp+'hyper_mskTC.snv.anno.nalurp',tmp+'hyper_mskTC.snv.anno.nrp',tmp+'hyper_mskTC.snv.anno.rmsrp')
            sprint.snv_cluster(tmp+'hyper_mskTC.snv.anno.rmsrp',tmp+'hyper_mskTC.res',cluster_distance,5)

            sprint.annotate(tmp+'hyper_mskAG.snv',repeat,tmp+'hyper_mskAG.snv.anno')
            sprint.seperate(tmp+'hyper_mskAG.snv.anno',tmp+'hyper_mskAG.snv.anno.alu',tmp+'hyper_mskAG.snv.anno.nalurp',tmp+'hyper_mskAG.snv.anno.nrp','Alu')
            sprint.combine_res(tmp+'hyper_mskAG.snv.anno.alu',tmp+'hyper_mskAG.snv.anno.nalurp',tmp+'hyper_mskAG.snv.anno.nrp',tmp+'hyper_mskAG.snv.anno.rmsrp')
            sprint.snv_cluster(tmp+'hyper_mskAG.snv.anno.rmsrp',tmp+'hyper_mskAG.res',cluster_distance,5)

            sprint.snv_or(tmp+'hyper_mskTC.res',tmp+'hyper_mskAG.res',tmp+'hyper.res')


            #sprint.o2b(tmp+'hyper_mskTC.res_tmp',tmp+'hyper.res')    
            #sprint.snv_cluster(tmp+'hyper.snv.anno.alu',tmp+'hyper_alu.res',cluster_distance,5)
            #sprint.snv_cluster(tmp+'hyper.snv.anno.nalurp',tmp+'hyper_nalurp.res',cluster_distance,5)
            #sprint.snv_cluster(tmp+'hyper.snv.anno.nrp',tmp+'hyper_nrp.res',cluster_distance,5)
            #sprint.combine_res(tmp+'hyper_alu.res',tmp+'hyper_nalurp.res',tmp+'hyper_nrp.res',tmp+'hyper.res')
            
    
     
        else:
            sprint.snv_cluster(tmp+'regular.snv',tmp+'regular.res_tmp',cluster_distance,5) 
            sprint.o2b(tmp+'regular.res_tmp',tmp+'regular.res') 

            sprint.snv_cluster(tmp+'hyper_mskTC.snv',tmp+'hyper_mskTC.res',cluster_distance,5)
            sprint.snv_cluster(tmp+'hyper_mskAG.snv',tmp+'hyper_mskAG.res',cluster_distance,5)
            sprint.snv_or(tmp+'hyper_mskTC.res',tmp+'hyper_mskAG.res',tmp+'hyper.res')

        try:
            subprocess.Popen('rm -rf '+tmp+'/*.anno.*',shell=True).wait()
        except Exception, e:
            pass
        
        if repeat !=False:
            sprint.get_res(tmp+'regular_alu.res',tmp+'regular_nalurp.res',tmp+'regular_nrp.res',  tmp+'hyper.res',  tmp+'SPRINT_identified')
            sprint.bed_sort(tmp+'SPRINT_identified_A_to_I_regular.res',tmp+'SPRINT_identified_A_to_I_regular.res_sort')
            sprint.bed_sort(tmp+'SPRINT_identified_A_to_I_hyper.res',tmp+'SPRINT_identified_A_to_I_hyper.res_sort')
            sprint.bed_sort(tmp+'SPRINT_identified_C_to_U.res',tmp+'SPRINT_identified_C_to_U.res_sort')
        
            sprint.o2b(tmp+'SPRINT_identified_A_to_I_regular.res_sort',output+'SPRINT_identified_A_to_I_regular.res')
            sprint.o2b(tmp+'SPRINT_identified_A_to_I_hyper.res_sort',output+'SPRINT_identified_A_to_I_hyper.res')
            sprint.o2b(tmp+'SPRINT_identified_C_to_U.res_sort',output+'SPRINT_identified_C_to_U.res')
        
            sprint.snv_or(tmp+'SPRINT_identified_A_to_I_hyper.res',tmp+'SPRINT_identified_A_to_I_regular.res',output+'SPRINT_identified_A_to_I_all.res') 

        subprocess.Popen('cp '+tmp+'/regular.res '+output+'/SPRINT_candidate_regular.res',shell=True).wait()
        subprocess.Popen('cp '+tmp+'/hyper.res '+output+'/SPRINT_candidate_hyper.res',shell=True).wait()
        sys.exit(0)
    #try:
    #    pass
    except Exception,e:
        print ''
        print 'ERROR!'
        print ''
        print e
        print ''
        help_doc()
    
    
    
    
    
    
    
 
#if __name__=='__main__':   
#    main()




from annotate import *
from seperate import *
from bed_sort import *
from snv_or import *
from o2b import *
from combine import *
from combine_res import *
from remove import *
from remain import *
from bed_or import *
from hyper_or import *




def get_baseq_cutoff(fq_in_dir=0,cutoff_out_dir=0):
	fi=open(fq_in_dir)
	fo=open(cutoff_out_dir,'w')
	line1=fi.readline()
	line2=fi.readline()
	line3=fi.readline()
	line4=fi.readline()
	did=0
	while line1 !='':
		if did==1:
			break
		qua=line4[0:-1]
		for i in qua:
			if ord(i) > 76:
				fo.write('89') #64+25
				did=1
				break
			if ord(i) < 60:
				fo.write('58') #33+25
				did=1
				break

		line1=fi.readline()
		line2=fi.readline()
		line3=fi.readline()
		line4=fi.readline()
	fi.close()
	fo.close()	



def get_snv_with_ad(snv_in_dir=0,snv_out_dir=0,flag=0):


	fi=open(snv_in_dir)
	fo=open(snv_out_dir,'w')
	
	for line in fi:
		seq=line.split('\t')
		try:
			if int(seq[4])>=int(flag):
				fo.write(line)
		except Exception, e:
			print seq[0]+'\t'+seq[2]+"\twithout\tAD flag\n"		



	fi.close()
	fo.close()




# coding: utf-8
import re
from tools_fq import *
from tools_sam import *
from tools_bed import *
from tools_zf import *
from tools_fa import *
import sprint_main
import sprint_prepare
from pipeline import *

#import __main__

#from __main__ import *

def main():
#   if __name__=="__main__":
       pipeline() 
    












"""

SPRINT

"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='sprint',
    version='0.1.1',
    description='A toolkit for accurately identifying RNA editing sites without the need to filter SNPs',
    long_description=long_description,
    url='http://sprint.tianlab.cn',
    author='Feng Zhang',
    author_email='15110700005@fudan.edu.cn',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for,

        
        'License :: OSI Approved :: MIT License',


        
        'Programming Language :: Python :: 2.7',
       
    ],

    
    keywords='RNA editing',

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    
    


    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },

    package_data={
        'sprint': ['package_data.dat'],
    },

    #data_files=[('my_data', ['data/data_file'])],
    entry_points={
        'console_scripts': [
            'sprint=sprint:main',
        ],
    },
)





def combine_depth(bed_in_dir=0,bed_out_dir=0):

	fi=open(bed_in_dir)# './zz_folder/all.zz')
	fo=open(bed_out_dir,'w')#'./tmp/readspersite_new.zer','w')
	for line in fi:
		seq=line[:-1].split('\t')
		AD=int(seq[4].split(':')[0])+int(seq[-1].split(':')[0])
		DP=int(seq[4].split(':')[1])+int(seq[-1].split(':')[1])
		
		fo.write(seq[0]+'\t'+seq[1]+'\t'+seq[2]+'\t'+seq[3]+'\t'+str(AD)+':'+str(DP)+'\t'+seq[5]+'\n')
	fi.close()
	fo.close()




def transcript_locator(fbed_in_dir=0,ftransloc_in_dir=0,fbed_out_dir=0):
    if fbed_in_dir==0 or ftransloc_in_dir==0:
        print 'fbed_in_dir\tftransloc_in_dir\tfbed_out_dir'
        return 0

    ftransloc=open(ftransloc_in_dir)
    fi=open(fbed_in_dir)
    fo=open(fbed_out_dir,'w')


    transcript={}
    whole=ftransloc.read().split('>')[1:]
    for one in whole:
        line=one.split('\n')
        transcript[line[0]]=line[1]
        #print line[0]


    for line in fi:
        seq=line.rstrip().split('\t')
        #print seq[0]
        if seq[0] in transcript:
            transcript_id=seq[0]
            chrr=transcript_id.split('_|_')[1]
            trans_loc=int(seq[2])
            loc=[]
            bande=transcript[seq[0]].split(';')[:-1]
            for one in bande:
                be=one.split(',')
                begin=int(be[0])
                end=int(be[1])
                tmp = [begin]*(end-begin+1)
                i=0
                while i< len(tmp):
                    tmp[i] = tmp[i]+i
                    i +=1
                loc += tmp
            ref_loc=loc[trans_loc-1]
            fo.write(chrr+'\t'+str(ref_loc-1)+'\t'+str(ref_loc)+'\t'+'\t'.join(seq[3:])+'\n')#'\t'+chrom[chrr][ref_loc-1]+':'+chrom_t[transcript_id][trans_loc-1]+'\n')

    









def dedup(in_dir,out_dir):
	old=set()
	fi=open(in_dir)
	fo=open(out_dir,'w')	
	for line in fi:
		seq=line.split('\t')
		if seq[0]+':'+seq[3]+':'+seq[7] not in old:
			fo.write(line)
			old.add(seq[0]+':'+seq[3]+':'+seq[7])
